# Welcome to SSP GH's documentation

```{toctree}
:hidden:
Overview <self>
dev/index
cli/index
api/index
reports/index
changelog
```

```{include} ../README.md
:start-line: 1
```

## 🔖 Indices and tables

* {ref}`genindex`
* {ref}`modindex`
* {ref}`search`
